<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt-BR" sourcelanguage="en">
  <context>
    <name>CmdMeshPartCrossSections</name>
    <message>
      <location filename="../../Command.cpp" line="269"/>
      <source>MeshPart</source>
      <translation>MeshPart</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="270"/>
      <source>Cross-sections...</source>
      <translation>Secções transversais...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="271"/>
      <source>Cross-sections</source>
      <translation>Secções transversais</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartCurveOnMesh</name>
    <message>
      <location filename="../../Command.cpp" line="305"/>
      <source>Mesh</source>
      <translation>Malha</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="306"/>
      <source>Curve on mesh...</source>
      <translation>Curva na malha...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="307"/>
      <source>Creates an approximated curve on top of a mesh.
This command only works with a 'mesh' object.</source>
      <translation>Cria uma curva aproximada sobre uma malha.
Este comando só funciona com um objeto do tipo "malha".</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartMesher</name>
    <message>
      <location filename="../../Command.cpp" line="58"/>
      <source>Mesh</source>
      <translation>Malha</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="59"/>
      <source>Create mesh from shape...</source>
      <translation>Criar malha a partir de uma forma...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="60"/>
      <source>Tessellate shape</source>
      <translation>Paginar forma</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartSection</name>
    <message>
      <location filename="../../Command.cpp" line="185"/>
      <source>Mesh</source>
      <translation>Malha</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="186"/>
      <source>Create section from mesh and plane</source>
      <translation>Criar a seção a partir da malha e plano</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="187"/>
      <source>Section</source>
      <translation>Seção</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartTrimByPlane</name>
    <message>
      <location filename="../../Command.cpp" line="83"/>
      <source>Mesh</source>
      <translation>Malha</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="84"/>
      <source>Trim mesh with a plane</source>
      <translation>Aparar malha numa superfície plana</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="85"/>
      <location filename="../../Command.cpp" line="86"/>
      <source>Trims a mesh with a plane</source>
      <translation>Apare uma malha numa superfície plana</translation>
    </message>
  </context>
  <context>
    <name>Command</name>
    <message>
      <location filename="../../Command.cpp" line="129"/>
      <source>Trim with plane</source>
      <translation>Recortar com um plano</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="208"/>
      <source>Section with plane</source>
      <translation>Seção com um plano</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::CrossSections</name>
    <message>
      <location filename="../../CrossSections.ui" line="14"/>
      <source>Cross sections</source>
      <translation>Secções transversais</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="20"/>
      <source>Guiding plane</source>
      <translation>Plano guia</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="26"/>
      <source>XY</source>
      <translation>XY</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="36"/>
      <source>XZ</source>
      <translation>XZ</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="43"/>
      <source>YZ</source>
      <translation>YZ</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="52"/>
      <source>Position:</source>
      <translation>Posição:</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="71"/>
      <source>Sections</source>
      <translation>Seções</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="83"/>
      <source>On both sides</source>
      <translation>Em ambos os lados</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="92"/>
      <source>Count</source>
      <translation>Quantidade</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="109"/>
      <source>Distance:</source>
      <translation>Distância:</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="128"/>
      <source>Options</source>
      <translation>Opções</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="134"/>
      <source>Connect edges if distance less than</source>
      <translation>Conecte as arestas se a distância for menor que</translation>
    </message>
    <message>
      <location filename="../../CrossSections.cpp" line="366"/>
      <source>Failure</source>
      <translation>Falha</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::CurveOnMeshHandler</name>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="364"/>
      <source>Create</source>
      <translation>Criar</translation>
    </message>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="366"/>
      <source>Close wire</source>
      <translation>Fechar aresta</translation>
    </message>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="368"/>
      <source>Clear</source>
      <translation>Limpar</translation>
    </message>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="369"/>
      <source>Cancel</source>
      <translation>Cancelar</translation>
    </message>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="615"/>
      <source>Wrong mesh picked</source>
      <translation>Malha errada escolhida</translation>
    </message>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="655"/>
      <source>No point was picked</source>
      <translation>Nenhum ponto foi escolhido</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::TaskCurveOnMesh</name>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="14"/>
      <source>Curve on mesh</source>
      <translation>Curva na malha</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="23"/>
      <source>Press 'Start', then pick points on the mesh; when enough points have been set, right-click and choose 'Create'. Repeat this process to create more splines. Close this task panel to complete the operation.

This command only works with a 'mesh' object, not a regular face or surface. To convert an object to a mesh use the tools of the Mesh Workbench.</source>
      <translation>Pressione 'Iniciar', depois selecione pontos na malha; quando pontos suficientes estiverem definidos, clique com o botão direito e escolha 'Criar'. Repita este processo para criar mais curvas spline. Feche este painel de tarefas para concluir a operação.

Este comando só funciona com um objeto 'malha', não com uma face ou superfície regular. Para converter um objeto em uma malha, use as ferramentas da Bancada de Trabalho Malha.</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="38"/>
      <source>Wire</source>
      <translation>Fio</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="44"/>
      <source>Snap tolerance to vertices</source>
      <translation>Tolerância de encaixe aos vértices</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="51"/>
      <source> px</source>
      <translation> px</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="61"/>
      <source>Split threshold</source>
      <translation>Limite de separação</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="87"/>
      <source>Spline Approximation</source>
      <translation>Aproximação de spline</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="96"/>
      <source>Tolerance to mesh</source>
      <translation>Tolerância da malha</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="122"/>
      <source>Continuity</source>
      <translation>Continuidade</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="136"/>
      <source>Maximum curve degree</source>
      <translation>Grau máximo da curva</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="153"/>
      <source>Start</source>
      <translation>Começar</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::Tessellation</name>
    <message>
      <location filename="../../Tessellation.ui" line="14"/>
      <source>Tessellation</source>
      <translation>Paginação</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="20"/>
      <source>Meshing options</source>
      <translation>Opções da engrenagem</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="30"/>
      <source>Standard</source>
      <translation>Padrão</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="33"/>
      <source>Use the standard mesher</source>
      <translation>Usar o gerador de malha padrão</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="41"/>
      <source>Surface deviation:</source>
      <translation>Desvio de superfície:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="48"/>
      <source>Maximal linear deflection of a mesh section from the surface of the object</source>
      <translation>Desvio linear máximo de uma seção de malha da superfície do objeto</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="67"/>
      <source>Angular deviation:</source>
      <translation>Desvio angular:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="74"/>
      <source>Maximal angular deflection of a mesh section to the next section</source>
      <translation>Desvio angular máximo de uma seção de malha para a próxima seção</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="98"/>
      <source>The maximal linear deviation of a mesh segment will be the specified
Surface deviation multiplied by the length of the current mesh segment (edge)</source>
      <translation>O desvio linear máximo de um segmento de malha será o desvio de superfície especificado
multiplicado pelo comprimento do segmento de malha atual (aresta)</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="102"/>
      <source>Relative surface deviation</source>
      <translation>Desvio relativo de superfície</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="109"/>
      <source>Mesh will get face colors of the object</source>
      <translation>A malha irá obter as cores da face do objeto</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="112"/>
      <source>Apply face colors to mesh</source>
      <translation>Aplicar cores do rosto de malha</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="119"/>
      <source>Mesh segments will be grouped according to the color of the object faces.
These groups will be exported for mesh output formats supporting
this feature (e.g. the format OBJ).</source>
      <translation>Os segmentos de malha serão agrupados de acordo com a cor das faces do objeto.
Esses grupos serão exportados para formatos de saída em malha que suportam
este recurso (por exemplo, o formato OBJ).</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="124"/>
      <source>Define segments by face colors</source>
      <translation>Definir segmentos por cores de rosto</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="145"/>
      <source>Mefisto</source>
      <translation>Mefisto</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="148"/>
      <source>Use the Mefisto mesher</source>
      <translation>Usar o gerador de malha Mefisto</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="156"/>
      <source>Maximum edge length:</source>
      <translation>Comprimento máximo da aresta:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="162"/>
      <source>If this number is smaller the mesh becomes finer.
The smallest value is 0.</source>
      <translation>Se este número for menor a malha se torna mais fina.
O menor valor possível é 0.</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="183"/>
      <source>Estimate</source>
      <translation>Estimar</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="206"/>
      <source>Netgen</source>
      <translation>Netgen</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="209"/>
      <source>Use the Netgen mesher</source>
      <translation>Usar o gerador de malha Netgen</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="217"/>
      <source>Fineness:</source>
      <translation>Espessura:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="234"/>
      <source>Very coarse</source>
      <translation>Muito grosso</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="239"/>
      <source>Coarse</source>
      <translation>Grosso</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="244"/>
      <source>Moderate</source>
      <translation>Moderado</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="249"/>
      <source>Fine</source>
      <translation>Fino</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="254"/>
      <source>Very fine</source>
      <translation>Muito fino</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="259"/>
      <source>User defined</source>
      <translation>Definidos pelo usuário</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="269"/>
      <source>Mesh size grading:</source>
      <translation>Classificação do tamanho da engrenagem:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="279"/>
      <source>If this parameter is smaller, the mesh becomes finer.
A value in the range of 0.1-1.</source>
      <translation>Se esse parâmetro for menor, a malha se torna mais fina.
Um valor na amplitude de 0.1-1.</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="302"/>
      <source>Elements per edge:</source>
      <translation>Elementos pela aresta:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="312"/>
      <location filename="../../Tessellation.ui" line="345"/>
      <source>If this parameter is larger, the mesh becomes finer.
A value in the range of 0.2-10.</source>
      <translation>Se esse parâmetro for maior, a malha se torna mais fina.
Um valor na amplitude de 0.2-10.</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="335"/>
      <source>Elements per curvature radius:</source>
      <translation>Elementos pelo raio da curvatura:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="370"/>
      <source>Whether optimization of surface shape will be done</source>
      <translation>Indica se a otimização da forma da superfície será feita</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="373"/>
      <source>Optimize surface</source>
      <translation>Otimizar a superfície</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="383"/>
      <source>Whether second order elements will be generated</source>
      <translation>Indica se os elementos de segunda ordem serão gerados</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="386"/>
      <source>Second order elements</source>
      <translation>Elementos de segunda ordem</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="393"/>
      <source>Whether meshes will be arranged preferably using quadrilateral faces</source>
      <translation>Indica se as malhas serão organizadas de preferência usando faces quadriláteras</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="396"/>
      <source>Quad dominated</source>
      <translation>O principal quadrilátero</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="422"/>
      <source>Leave panel open</source>
      <translation>Deixar painel aberto</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="61"/>
      <source>Gmsh</source>
      <translation>Gmsh</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="225"/>
      <location filename="../../Tessellation.cpp" line="231"/>
      <source>No active document</source>
      <translation>Nenhum documento ativo</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="259"/>
      <source>You have selected a body without tip.
Either set the tip of the body or select a different shape, please.</source>
      <translation>Você selecionou um corpo sem ponta.
Por favor, defina a ponta do corpo ou selecione uma forma diferente.</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="263"/>
      <source>You have selected a shape without faces.
Select a different shape, please.</source>
      <translation>Você selecionou uma forma sem faces.
Por favor, selecione uma forma diferente.</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="267"/>
      <source>Select a shape for meshing, first.</source>
      <translation>Selecione primeiro uma forma para malhagem.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_Section</name>
    <message>
      <location filename="../../Command.cpp" line="198"/>
      <source>Select plane</source>
      <translation>Selecionar plano</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="199"/>
      <source>Please select a plane at which you section the mesh.</source>
      <translation>Favor selecione um plano em que possa aparar a malha.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_TrimByPlane</name>
    <message>
      <location filename="../../Command.cpp" line="95"/>
      <source>Select plane</source>
      <translation>Selecionar plano</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="96"/>
      <source>Please select a plane at which you trim the mesh.</source>
      <translation>Favor selecionar um plano em que possa aparar a malha.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="102"/>
      <source>Trim by plane</source>
      <translation>Cortar por plano</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="103"/>
      <source>Select the side you want to keep.</source>
      <translation>Selecione o lado que deseja manter.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="104"/>
      <source>Below</source>
      <translation>Abaixo</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="105"/>
      <source>Above</source>
      <translation>Acima</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="106"/>
      <source>Split</source>
      <translation>Separar</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="36"/>
      <source>MeshPart</source>
      <translation>MeshPart</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_CreateFlatMesh</name>
    <message>
      <location filename="../../MeshFlatteningCommand.py" line="47"/>
      <source>Unwrap Mesh</source>
      <translation type="unfinished">Unwrap Mesh</translation>
    </message>
    <message>
      <location filename="../../MeshFlatteningCommand.py" line="50"/>
      <source>Find a flat representation of a mesh.</source>
      <translation type="unfinished">Find a flat representation of a mesh.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_CreateFlatFace</name>
    <message>
      <location filename="../../MeshFlatteningCommand.py" line="79"/>
      <source>Unwrap Face</source>
      <translation type="unfinished">Unwrap Face</translation>
    </message>
    <message>
      <location filename="../../MeshFlatteningCommand.py" line="82"/>
      <source>Find a flat representation of a face.</source>
      <translation type="unfinished">Find a flat representation of a face.</translation>
    </message>
  </context>
</TS>
